Usage
loadnetwork(filename,useSparseMatrix=NULL,minN=50)
loadnetwork2(filename,useSparseMatrix=NULL,minN=50)
savenetwork(n, filename, twomode = "default", symetric = NULL)
loadmatrix(filename)
savematrix(n, filename, twomode = 1)
loadvector(filename)
loadvector2(filename)
savevector(v, filename)
loadpajek(filename)
Arguments
filename
The name of the filename to be loaded or saved to or an open file object.
useSparseMatrix
Should a sparse matrix be use instead of the ordinary one? Sparse matices can only be used if package Matrix is installed. The default NULL uses sparsematrices for networks with more that minN vertices
minN
The minimal number of units in the network to use sparse matrices.
n
A matrix representing the network.
twomode
1 for one-mode networks and 2 for two-mode networks. Default sets the argument to 1 for square matrices and to 2 for others.
symetric
If true, only the lower part of the matrix is used and the values are interpreted as "Edges", not "Arcs".