Usage
find.m(M, clu, alt.blocks = "reg", diag = !is.list(clu),
cormet = "none", half = TRUE, FUN = "max")
find.m2(M, clu, alt.blocks = "reg", neval = 100, half = TRUE,
ms = NULL, ...)
find.cut(M, clu, alt.blocks = "reg", cuts = "all", ...)Arguments
M
A matrix representing the (usually valued) network. For now, only one-relational networks are supported. The network can have one or more modes (diferent kinds of units with no ties among themselvs. If the network is not two-mode, the matrix must be squar
clu
A partition. Each unique value represents one cluster. If the nework is one-mode, than this should be a vector, else a list of vectors, one for each mode
alt.blocks
Only one of allowed blocktypes, as alternative to the null block:
"com" - complete block
"rdo", "cdo" - row and column-dominant blocks (binary, valued, and implicit approach only)
"reg" - (f-)regular block
"rre", "cre" - row and column-(f-)regular blocks
diag
(default = TRUE) Should the special stauts of diagonal be acknowladged.
cormet
Which metho should be used to correct for diferent maxismum error contributins?
"none" - no correction
"censor" - censor values larger than m
"correct" - so that the maxsimum possible error contribution of the cell is the same regardles of a condition (e
FUN
(default = "max") Function f used in row-f-regular, column-f-regular, and f-regular blocks.
cuts
The cuts which should be evaluatated. If cuts="all"n (default), all unique values are evaluated
neval
Number of different m values to be evaluated.
half
Should the returned value of m be one half of the value where the incosnistencies are the same.
ms
The values of m where the function should be evaluated.
...
Other parameters to crit.fun