Usage
gplot1(M, diag = TRUE, displaylabels = TRUE, boxed.labels = FALSE,
loop.cex = 4, arrowhead.cex = NULL, arrowheads.fun = "sqrt",
edge.lwd = 1, edge.col = "default", rel.thresh = 0.05, ...)
gplot2(M, uselen = TRUE, usecurve = TRUE, edge.len = 0.001,
diag = TRUE, displaylabels = TRUE, boxed.labels = FALSE,
loop.cex = 4, arrowhead.cex = 2.5, edge.lwd = 1,
edge.col = "default", rel.thresh = 0.05, ...)
Arguments
M
A matix (array) of a graph or set thereof. This data may be valued.
diag
boolean indicating whether or not the diagonal should be treated as valid data. Set this true if and only if the data can contain loops. diag is FALSE by default.
rel.thresh
real number indicating the lower relative (compared to the highest value) threshold for tie values. Only ties of value >thresh are displayed. By default, thresh=0.
displaylabels
boolean; should vertex labels be displayed?
boxed.labels
boolean; place vertex labels within boxes?
arrowhead.cex
An expansion factor for edge arrowheads.
arrowheads.fun
A function for scaling arrowheands.
loop.cex
expansion factor for loops; may be given as a vector, if loops are to be of different sizes.
edge.col
color for edges; may be given as a vector or adjacency matrix, if edges are to be of different colors.
edge.lwd
line width scale for edges; if set greater than 0, edge widths are scaled by edge.lwd*dat. May be given as a vector or adjacency matrix, if edges are to have different line widths.
edge.len
if uselen==TRUE, curved edge lengths are scaled by edge.len.
uselen
boolean; should we use edge.len to rescale edge lengths?
usecurve
boolean; should we use edge.curve?
...
additional arguments to plot or gplot from package sna:
mode: the vertex placement algorithm; this must correspond to a gplot.layout function from p